==> prestashop_1.5.1.0.zip: prestashop/modules/statsregistrations/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Cuentas cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Mostrar la progresión de la suscripción de clientes';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visitantes que no han pasado de la suscripción:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'Visitantes que han efectuado un pedido directamente después de suscribirse:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total cuentas cliente:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'CSV Export';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Número de clientes que han creado una cuenta';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'El número total de cuentas creadas no es en sí misma información importante. Sin embargo, es interesante analizar la cantidad creada en un cierto plazo. Esto indicará de una manera u otra  si las cosas van por buen camino.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = '¿Cómo intervenir en la evolución de las suscripciones?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'i usted deja su tienda funcionar sin realizar cambios, el número de suscripciones de cliente puede permanecer estable o declinar levemente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Un aumento significativo o una disminución demuestra que ha habido probablemente un cambio en su tienda; por lo tanto,  usted debe identificarlo y dar marcha atrás si ha habido una disminución de suscripciones o continuar con él si es ventajoso.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'AquÃ­ se muestra un sumario de lo que puede afectar  a la hora de crear cuentas de clientes.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Una campaña publicitaria puede atraer un mayor número de visitantes.Un incremento de clientes registrados le dará cierta seguridad, pero depende de su \"calidad\": una publicidad bien dirigida puede resultar más efectiva que un campaña a gran escala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Ofertas especiales, rebajas o contenidos crean grandes espectativas y curiosidad, así no sólo se mantiene activo su comercio activo sino que además aumenta el tráfico. De esta manera, puede captar clientes impulsivos.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'El diseño y la accesibilidad son más importantes que nunca: una mala accesibilidad o una mala presentación gráfica puede hacer que sus visitantes se vayan. Tiene que crear un balance entre un diseño innovador que permita al visitante moverse por la red con comodidad. Un escritura clara y correcta también inspirarán más confianza para el cliente hacia su comercio.';

==> prestashop_1.5.3.1.zip: prestashop/modules/statsregistrations/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visitantes que no han pasado de la suscripción:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'i usted deja su tienda funcionar sin realizar cambios, el número de suscripciones de cliente puede permanecer estable o declinar levemente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'AquÃ­ se muestra un sumario de lo que puede afectar  a la hora de crear cuentas de clientes.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Una campaña publicitaria puede atraer un mayor número de visitantes.Un incremento de clientes registrados le dará cierta seguridad, pero depende de su \\"calidad\\": una publicidad bien dirigida puede resultar más efectiva que un campaña a gran escala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'El número total de cuentas creadas no es en sí misma información importante. Sin embargo, es interesante analizar la cantidad creada en un cierto plazo. Esto indicará de una manera u otra  si las cosas van por buen camino.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Cuentas cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = '¿Cómo intervenir en la evolución de las suscripciones?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Un aumento significativo o una disminución demuestra que ha habido probablemente un cambio en su tienda; por lo tanto,  usted debe identificarlo y dar marcha atrás si ha habido una disminución de suscripciones o continuar con él si es ventajoso.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'El diseño y la accesibilidad son más importantes que nunca: una mala accesibilidad o una mala presentación gráfica puede hacer que sus visitantes se vayan. Tiene que crear un balance entre un diseño innovador que permita al visitante moverse por la red con comodidad. Un escritura clara y correcta también inspirarán más confianza para el cliente hacia su comercio.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Mostrar la progresión de la suscripción de clientes';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'Visitantes que han efectuado un pedido directamente después de suscribirse:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'CSV Export';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Número de clientes que han creado una cuenta';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Ofertas especiales, rebajas o contenidos crean grandes espectativas y curiosidad, así no sólo se mantiene activo su comercio activo sino que además aumenta el tráfico. De esta manera, puede captar clientes impulsivos.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total cuentas cliente:';
